thermferm/thermferm.h

changeset 313
8448fcf3d799
parent 310
53774295e14a
child 339
16203280eea2
--- a/thermferm/thermferm.h	Mon Feb 16 19:52:42 2015 +0100
+++ b/thermferm/thermferm.h	Mon Feb 16 20:41:09 2015 +0100
@@ -151,8 +151,8 @@
     float		prof_peak_abs;		/* Profile absolute peak temp	*/
     float		prof_peak_rel;		/* Profile relative peak temp	*/
     time_t		prof_primary_done;	/* Profile primary is done	*/
-    float		PID_I_err;		/* PID Integral error		*/
-    float		PID_err_old;		/* PID old error value		*/
+    double		PID_iState;		/* PID Integral state		*/
+    double		PID_dState;		/* PID last measured value	*/
     float		PID_Kp;			/* PID Kp setting		*/
     float		PID_Kd;			/* PID Kd setting		*/
     float		PID_Ki;			/* PID Ki setting		*/

mercurial